@@ -1,7 +1,8 @@
-#!/usr/bin/perl -W
+#!/usr/bin/env perl
+use warnings;
 #
 # XASTIR, Amateur Station Tracking and Information Reporting
-# Copyright (C) 2000-2018 The Xastir Group
+# Copyright (C) 2000-2019 The Xastir Group
 #
 # Converts "dump1090" telnet port output to Xastir UDP input, for decoding
 # packets directly from aircraft.  This script will parse packets containing
@@ -198,7 +199,7 @@ $dump1090_port = 30003;     # 30003 is dump1090 default port
 $xastir_host = "localhost"; # Server where Xastir is running
 $xastir_port = 2023;        # 2023 is Xastir default UDP port
 
-$plane_TTL = 15;            # Secs after which posits too old to create APRS packets from
+$plane_TTL = 1;            # Secs after which posits too old to create APRS packets from
 
 $log_file = "~/.xastir/logs/planes.log";
 
@@ -943,19 +944,21 @@ while (<$socket>)
     }
 
     # Save new tail number or flight number, assign tactical call
-    $tail{$plane_id} = $fields[10];
+    $temp_tail = $fields[10];
+    $temp_tail =~ s/[^a-zA-Z0-9,]//g; # Filter out all but alphanumeric chars
+    $tail{$plane_id} = $temp_tail;
     $tail{$plane_id} =~ s/\s//g;    # Remove spaces
 
     if ($old ne $tail{$plane_id}) {
-      $print6 = sprintf("%-18s", $fields[10]);
+      $print6 = sprintf("%-18s", $temp_tail);
       $newdata{$plane_id}++;    # Found a new tail or flight number!
  
       # Assign tactical call = tail number or flight number + registry (if defined)
       # Max tactical call in Xastir is 57 chars (56 + terminator?)
       #
-      $tactical{$plane_id} = $fields[10];
+      $tactical{$plane_id} = $temp_tail;
       if ($registry ne "Registry?") {
-        $tactical{$plane_id} = $fields[10] . " (" . $registry . ")";
+        $tactical{$plane_id} = $temp_tail . " (" . $registry . ")";
         $tactical{$plane_id} =~ s/\s+/ /g; # Change multiple spaces to one
       }
       $aprs = $xastir_user . '>' . "APRS::TACTICAL :" . $plane_id . "=" . $tactical{$plane_id};
